@@ -1,7 +1,8 @@
 from django.conf.urls.defaults import patterns, url
 from .views import (
     AggregateHistoryView, AggregateDetailView, AggregateFormView,
-    CategoryFormView, MetricDetailView, MetricHistoryView, MetricsListView,
+    CategoryFormView, DefaultView, GaugesView, MetricDetailView,
+    MetricHistoryView, MetricsListView,
 )
 
 
@@ -21,6 +22,12 @@ urlpatterns = patterns('',
     url(r'^aggregate/$',
         AggregateFormView.as_view(),
         name='redis_metric_aggregate'),
+    url(r'^list/$',
+        MetricsListView.as_view(),
+        name='redis_metrics_list'),
+    url(r'^gauges/$',
+        GaugesView.as_view(),
+        name='redis_metrics_gauges'),
     url(r'^(?P<slug>.*)/(?P<granularity>.*)/$',
         MetricHistoryView.as_view(),
         name='redis_metric_history'),
@@ -28,6 +35,6 @@ urlpatterns = patterns('',
         MetricDetailView.as_view(),
         name='redis_metric_detail'),
     url(r'^$',
-        MetricsListView.as_view(),
-        name='redis_metrics_list'),
+        DefaultView.as_view(),
+        name='redis_metrics_default'),
 )
